@@ -71,16 +71,11 @@ on_mainwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	}
 
 	if (logchanged)
-	{
 		create_savedialog ();
-		return (TRUE);
-	}
 	else
-	{
-		save_windowsize_and_cleanup ();
-		gtk_main_quit ();
-		return (FALSE);
-	}
+		create_exitdialog ();
+
+	return (TRUE);
 }
 
 /* switch between pages of the notebook */
@@ -119,55 +114,55 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	{
 	case GDK_F1:
 		f1button = lookup_widget (keyerwindow, "f1button");
-		g_signal_emit_by_name (G_OBJECT (f1button), "activate");
+		gtk_widget_activate (f1button);
 	break;
 	case GDK_F2:
 		f2button = lookup_widget (keyerwindow, "f2button");
-		g_signal_emit_by_name (G_OBJECT (f2button), "activate");
+		gtk_widget_activate (f2button);
 	break;
 	case GDK_F3:
 		f3button = lookup_widget (keyerwindow, "f3button");
-		g_signal_emit_by_name (G_OBJECT (f3button), "activate");
+		gtk_widget_activate (f3button);
 	break;
 	case GDK_F4:
 		f4button = lookup_widget (keyerwindow, "f4button");
-		g_signal_emit_by_name (G_OBJECT (f4button), "activate");
+		gtk_widget_activate (f4button);
 	break;
 	case GDK_F5:
 		f5button = lookup_widget (keyerwindow, "f5button");
-		g_signal_emit_by_name (G_OBJECT (f5button), "activate");
+		gtk_widget_activate (f5button);
 	break;
 	case GDK_F6:
 		f6button = lookup_widget (keyerwindow, "f6button");
-		g_signal_emit_by_name (G_OBJECT (f6button), "activate");
+		gtk_widget_activate (f6button);
 	break;
 	case GDK_F7:
 		f7button = lookup_widget (keyerwindow, "f7button");
-		g_signal_emit_by_name (G_OBJECT (f7button), "activate");
+		gtk_widget_activate (f7button);
 	break;
 	case GDK_F8:
 		f8button = lookup_widget (keyerwindow, "f8button");
-		g_signal_emit_by_name (G_OBJECT (f8button), "activate");
+		gtk_widget_activate (f8button);
 	break;
 	case GDK_F9:
 		f9button = lookup_widget (keyerwindow, "f9button");
-		g_signal_emit_by_name (G_OBJECT (f9button), "activate");
+		gtk_widget_activate (f9button);
 	break;
 	case GDK_F10:
 		f10button = lookup_widget (keyerwindow, "f10button");
-		g_signal_emit_by_name (G_OBJECT (f10button), "activate");
+		gtk_widget_activate (f10button);
 	break;
 	case GDK_F11:
 		f11button = lookup_widget (keyerwindow, "f11button");
-		g_signal_emit_by_name (G_OBJECT (f11button), "activate");
+		gtk_widget_activate (f11button);
 	break;
 	case GDK_F12:
 		f12button = lookup_widget (keyerwindow, "f12button");
-		g_signal_emit_by_name (G_OBJECT (f12button), "activate");
+		gtk_widget_activate (f12button);
 	break;
 	case GDK_Escape:
 		stopbutton = lookup_widget (keyerwindow, "stopbutton");
-		g_signal_emit_by_name (G_OBJECT (stopbutton), "activate");
+		gtk_widget_activate (stopbutton);
 	break;
 	case GDK_Return:
 		myrstentry = lookup_widget (mainwindow, "myrstentry");
@@ -193,12 +188,12 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 				if (keyerstate.cqmode)
 				{
 					f3button = lookup_widget (keyerwindow, "f3button");
-					g_signal_emit_by_name (G_OBJECT (f3button), "activate");
+					gtk_widget_activate (f3button);
 				}
 				else
 				{
 					f6button = lookup_widget (keyerwindow, "f6button");
-					g_signal_emit_by_name (G_OBJECT (f6button), "activate");
+					gtk_widget_activate (f6button);
 				}
 
 				/* fill in defaults, check if we use a counter */
@@ -236,12 +231,12 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 				if (keyerstate.cqmode)
 				{	/* call CQ */
 					f1button = lookup_widget (keyerwindow, "f1button");
-					g_signal_emit_by_name (G_OBJECT (f1button), "activate");
+					gtk_widget_activate (f1button);
 				}
 				else
 				{
 					f6button = lookup_widget (keyerwindow, "f6button");
-					g_signal_emit_by_name (G_OBJECT (f6button), "activate");
+					gtk_widget_activate (f6button);
 				}
 			}
 		}
