@@ -98,14 +98,9 @@ on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 	}
 
 	if (logchanged)
-	{
 		create_savedialog ();
-	}
 	else
-	{
-		save_windowsize_and_cleanup ();
-		gtk_main_quit ();
-	}
+		create_exitdialog ();
 }
 
 /* save current page to the log */
