@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -45,7 +45,7 @@
 #include "callbacks_mainwindow_qsoframe.h"
 #include "support.h"
 #include "dxcc.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "xlog_enum.h"
 #include "utils.h"
 #include "gui_utils.h"
@@ -147,6 +147,26 @@ result[i] = islower (new_text[i]) ? toupper (new_text[i]) : new_text[i];
 	g_free (result);
 }
 
+void
+on_callbutton_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *entry;
+
+	entry = lookup_widget (mainwindow, "callentry");
+	gchar *call = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (strlen(call) > 2)
+	{
+		if (g_strrstr (preferences.openurl, "<call>"))
+		{
+			gchar *link = g_strdup (preferences.openurl);
+			link = my_strreplace (link, "<call>", call);
+			open_url (link);
+			g_free (link);
+		}
+	}
+	g_free (call);
+}
+
 static void
 updateb4window_and_typeaheadfind (gchar * callsign)
 {
@@ -232,7 +252,7 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 						g_free (entry);
 					}
 					remarksvbox = lookup_widget(mainwindow, "remarksvbox");
-					if (!g_ascii_strcasecmp (preferences.defaultremarks, "?")
+					if (strlen (preferences.defaultremarks) == 0
 						&& GTK_WIDGET_VISIBLE (remarksvbox))
 					{
 						remtv = lookup_widget(mainwindow, "remtv");
@@ -361,7 +381,7 @@ on_mhzbutton_clicked (GtkButton * button, gpointer user_data)
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 
 	/* set optionmenu and entry to the default */
-	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
+	if (strlen (preferences.defaultmhz) > 0)
 	{
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultmhz);
 		bandenum = freq2enum (preferences.defaultmhz);
@@ -396,7 +416,7 @@ on_modebutton_clicked (GtkButton * button, gpointer user_data)
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 
 	/* use default */
-	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
+	if (strlen (preferences.defaultmode) > 0)
 	{
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultmode);
 		modeenum = mode2enum (preferences.defaultmode);
@@ -423,10 +443,10 @@ on_rstbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *rstentry, *count;
 	gint c;
-	gchar *str, *countstr;
+	gchar *str, *countstr, *lastmsg;
 
 	rstentry = lookup_widget (mainwindow, "rstentry");
-	if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
+	if (strlen (preferences.defaulttxrst) > 0)
 	{
 		if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
 		{
@@ -443,6 +463,14 @@ on_rstbutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_entry_set_text (GTK_ENTRY (rstentry), str);
 			g_free (str);
 		}
+		else if (keyerwindow && g_strrstr (preferences.defaulttxrst, "~"))
+		{
+			lastmsg = get_last_msg ();
+			str = my_strreplace (preferences.defaulttxrst, "~", lastmsg);
+			g_free (lastmsg);
+			gtk_entry_set_text (GTK_ENTRY (rstentry), str);
+			g_free (str);
+		}
 		else
 			gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
 	}
@@ -459,7 +487,7 @@ on_powerbutton_clicked (GtkButton * button, gpointer user_data)
 	gchar *rigpower;
 
 	entry = lookup_widget (mainwindow, "powerentry");
-	if (g_ascii_strcasecmp (preferences.defaultpower, "?"))
+	if (strlen (preferences.defaultpower) > 0)
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultpower);
 	else if (programstate.rigpower != 0)
 		{
@@ -551,7 +579,7 @@ entry_mnemonic_activate (GtkWidget *entry, gboolean arg1, gpointer user_data)
 void
 tv_mnemonic_activate (GtkWidget *tv, gboolean arg1, gpointer user_data)
 {
-	if (g_ascii_strcasecmp (preferences.defaultremarks, "?"))
+	if (strlen (preferences.defaultremarks) > 0)
 	{
 		GtkTextBuffer *b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tv));
 		gtk_text_buffer_set_text (b, preferences.defaultremarks, -1);
@@ -565,7 +593,7 @@ bandoptionactivate (GtkWidget *bandoptionmenu, gboolean arg1, gpointer user_data
 {
 	guint bandenum;
 
-	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
+	if (strlen (preferences.defaultmhz) > 0)
 	{
 		bandenum = freq2enum (preferences.defaultmhz);
 		if (bandenum >= 0)
@@ -582,7 +610,7 @@ modeoptionactivate (GtkWidget *modeoptionmenu, gboolean arg1, gpointer user_data
 {
 	guint modeenum;
 
-	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
+	if (strlen (preferences.defaultmode) > 0)
 	{
 		modeenum = mode2enum (preferences.defaultmode);
 		if (modeenum >= 0)
