@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,20 +25,22 @@
  */
 
 #include <gtk/gtk.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <glib/gstdio.h>
+
 #include "dxcc.h"
 #include "gc.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "xlog_enum.h"
 #include "awards_enum.h"
 #include "utils.h"
 #include "main.h"
 #include "log.h"
+#include "gui_countrymap.h"
 
-extern GtkWidget *mainwindow, *scorewindow;
+extern GtkWidget *mainwindow, *scorewindow, *countrymap;
 extern preferencestype preferences;
 extern programstatetype programstate;
 extern GList *logwindowlist;
@@ -133,6 +135,8 @@ findpfx_in_exception (gchar * pfx)
 			break;
 		}
 	}
+	if (pfx[0] == '=')
+		return pfx + 1;
 	return pfx;
 }
 
@@ -357,29 +361,68 @@ area_add (gchar *c, gint w, gint i, gchar *cont, gint lat, gint lon,
 	g_ptr_array_add (area, new_area);
 }
 
+gint
+readctyversion (void)
+{
+	gchar buf[65536], *ver, *ch, *cty_location;
+	FILE *fp;
+
+#ifdef G_OS_WIN32
+	cty_location = g_strconcat ("dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
+#else
+	cty_location = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
+#endif
+	if ((fp = g_fopen (cty_location, "r")) == NULL)
+	{
+		g_free (cty_location);
+		return (1);
+	}
+	g_free (cty_location);
+	gint n = fread (buf, 1, 65536, fp);
+	buf[n] = '\0';
+	ver = strstr (buf, "VER2");
+	if (ver)
+	{
+		ch = strstr (ver, ",");
+		if (ch)
+		{
+			*ch = '\0';
+			fclose (fp);
+			return atoi(ver+3);
+		}
+	}
+	fclose (fp);
+	return 0;
+}
+
 /* fill the hashtable with all of the prefixes from cty.dat */
 gint
 readctydata (void)
 {
 
-	gchar buf[4096], *cty_location, *pfx, **split, **pfxsplit;
+	gchar buf[8192], *cty_location, *pfx, **split, **pfxsplit;
 	gint ichar = 0, dxccitem = 0, ipfx = 0, ch = 0;
 	gboolean firstcolon = FALSE;
 	FILE *fp;
 
+#ifdef G_OS_WIN32
+	cty_location = g_strconcat ("dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
+#else
 	cty_location = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
+#endif
 
-	if ((fp = fopen (cty_location, "r")) == NULL)
+	if ((fp = g_fopen (cty_location, "r")) == NULL)
 	{
 		g_free (cty_location);
 		return (1);
 	}
+	g_free (cty_location);
 
 	dxcc = g_ptr_array_new ();
 	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
 	/* first field in case hash_table_lookup returns NULL */
-	dxcc_add ("Unknown", 0, 0, 99, 0, 0, 0, "", "");
+	dxcc_add (_("Unknown"), 0, 0, 99, 0, 0, 0, "", "");
 	programstate.countries = 1;
 
 	while (!feof (fp))
@@ -415,9 +458,7 @@ readctydata (void)
 			(gint)(strtod(split[4], NULL) * 100), (gint)(strtod(split[5], NULL) * 100),
 			(gint)(strtod(split[6], NULL) * 10), split[7], split[8]);
 
-		/* official prefix */
-		g_hash_table_insert (prefixes, g_strdup (split[7]),
-			GINT_TO_POINTER (programstate.countries));
+		/* NOTE: split[7] is the description prefix, it is not added to the hashtable */
 
 		/* split up the second line */
 		pfxsplit = g_strsplit (split[8], ",", 0);
@@ -426,9 +467,7 @@ readctydata (void)
 		{
 			if (!pfxsplit[ipfx]) break;
 			pfx = findpfx_in_exception (pfxsplit[ipfx]);
-			if (g_ascii_strcasecmp(pfx, split[7]) != 0)
-				g_hash_table_insert (prefixes, g_strdup (pfx),
-			GINT_TO_POINTER (programstate.countries));
+			g_hash_table_insert (prefixes, g_strdup (pfx), GINT_TO_POINTER (programstate.countries));
 		}
 		g_strfreev (pfxsplit);
 		g_strfreev (split);
@@ -436,7 +475,6 @@ readctydata (void)
 		}
 	}
 	fclose (fp);
-	g_free (cty_location);
 	return (0);
 }
 
@@ -449,9 +487,12 @@ readareadata (void)
 	gint ichar = 0, ch = 0;
 	FILE *fp;
 
+#ifdef G_OS_WIN32
+	area_location = g_strconcat ("dxcc", G_DIR_SEPARATOR_S, "area.dat", NULL);
+#else
 	area_location = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "area.dat", NULL);
-
-	if ((fp = fopen (area_location, "r")) == NULL)
+#endif
+	if ((fp = g_fopen (area_location, "r")) == NULL)
 	{
 		g_free (area_location);
 		return (1);
@@ -566,6 +607,14 @@ updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont,
 	{
 		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, d->px, -1);
+		if (countrymap)
+		{
+			if (strcmp (programstate.px, d->px))
+			{
+				countrymap_refresh (d->px);
+				programstate.px = g_strdup (d->px);
+			}
+		}
 		iter_num[0]++;
 		for (j = 0; j < MAX_BANDS; j++)
 		{
@@ -759,26 +808,33 @@ updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont,
 	cqtext = g_strdup_printf ("CQ %d", lookup.cq);
 	labeltext3 = g_strdup_printf (_("Timezone: %+1.1f"), (gdouble)d->timezone/10);
 
+	/* to facilitate language translations */
+	const char *north = _("N");
+	const char *south = _("S");
+	const char *east = _("E");
+	const char *west = _("W");
+	const char *loc = _("Location");
+
 	if (d->latitude >= 0 && d->longitude >= 0)
-	labeltext4 = g_strdup_printf (_("Location: %1.2fN %1.2fW"),
-		(gdouble)d->latitude/100, (gdouble)d->longitude/100);
+	labeltext4 = g_strdup_printf ("%s: %1.2f%s %1.2f%s",
+		loc, (gdouble)d->latitude/100, north, (gdouble)d->longitude/100, west);
 	else if (d->latitude >= 0 && d->longitude < 0)
-	labeltext4 = g_strdup_printf (_("Location: %1.2fN %1.2fE"),
-		(gdouble)d->latitude/100, -1 * (gdouble)d->longitude/100);
+	labeltext4 = g_strdup_printf ("%s: %1.2f%s %1.2f%s",
+		loc, (gdouble)d->latitude/100, north, -1 * (gdouble)d->longitude/100, east);
 	else if (d->latitude < 0 && d->longitude >= 0)
-	labeltext4 = g_strdup_printf (_("Location: %1.2fS %1.2fW"),
-		-1 * (gdouble)d->latitude/100, (gdouble)d->longitude/100);
+	labeltext4 = g_strdup_printf ("%s: %1.2f%s %1.2f%s",
+		loc, -1 * (gdouble)d->latitude/100, south, (gdouble)d->longitude/100, west);
 	else
-	labeltext4 = g_strdup_printf (_("Location: %1.2fS %1.2fE"),
-		-1 * (gdouble)d->latitude/100, -1 * (gdouble)d->longitude/100);
+	labeltext4 = g_strdup_printf ("%s: %1.2f%s %1.2f%s",
+		loc, -1 * (gdouble)d->latitude/100, south, -1 * (gdouble)d->longitude/100, east);
 	
 	if (lookup.country > 0)
 	{
-		if (preferences.NS == 0)
+		if (preferences.NS == 1)
 			lat = -1.0 * preferences.latitude;
 		else
 			lat = preferences.latitude;
-		if (preferences.EW == 0)
+		if (preferences.EW == 1)
 			lon = -1.0 * preferences.longitude;
 		else
 			lon = preferences.longitude;
@@ -1057,9 +1113,9 @@ void loc_new_qso(const gchar *locator, gint f, gboolean qslconfirmed)
 {
 	gchar *loc4;
 
+	if (!locator || strlen(locator) < 4) return;
 	loc4 = loc_norm(locator);
-	if (!loc4)
-		return;
+	if (!loc4) return;
 
 	hash_inc(loc_w[f], loc4);
 	hash_inc(loc_w[MAX_BANDS], loc4);
@@ -1075,13 +1131,11 @@ void loc_new_qso(const gchar *locator, gint f, gboolean qslconfirmed)
 
 void loc_del_qso(const gchar *locator, gint f, gboolean qslconfirmed)
 {
-	gchar loc4[5];
+	gchar *loc4;
 
-	if (!locator || strlen(locator) < 4)
-		return;
-
-	memcpy(loc4, locator, 4);
-	loc4[4] = '\0';
+	if (!locator || strlen(locator) < 4) return;
+	loc4 = loc_norm(locator);
+	if (!loc4) return;
 
 	hash_dec(loc_w[f], loc4);
 	hash_dec(loc_w[MAX_BANDS], loc4);
@@ -1206,7 +1260,7 @@ void fill_scoring_arrays (void)
 			else
 				lookup = lookupcountry_by_callsign (call);
 
-			if (preferences.scoringbands[f] == '1')
+			if (preferences.scoringbands[f] == 1)
 			{
 				qslconfirmed = qslreceived (qslin);
 				if (lookup.country > 0)
