@@ -44,7 +44,7 @@ void on_awards_dxcc_activate (GtkMenuItem *menuitem, gpointer user_data)
 		warningdialog (_("xlog - DXCC award"),
 			_("Please enable the scoring window"), "gtk-dialog-warning");
 	GtkWidget *dialog = gtk_dialog_new_with_buttons (_("xlog - DXCC award"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),	GTK_STOCK_OK, GTK_RESPONSE_OK);
 	gtk_widget_set_size_request (dialog, 450, 500);
 
