@@ -56,7 +56,7 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 		if (logwindow->logchanged)
 		{
 			closedialog = gtk_dialog_new_with_buttons (_("xlog - closing"),
-				GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 			vbox = gtk_vbox_new (TRUE, 0);
