@@ -65,6 +65,9 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
     	GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, 
 		GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
+		gtk_window_set_modal (GTK_WINDOW(exportdialog), TRUE);
+		gtk_window_set_destroy_with_parent (GTK_WINDOW(exportdialog), TRUE);
+
 		/* optionmenu for the file types */
 		hbox = gtk_hbox_new (FALSE, 0);
 		label = gtk_label_new (_("Type of log:"));
@@ -147,7 +150,7 @@ update_statusbar(_("Cannot export log: invalid entry for first and/or last QSO")
 			{
 				exportwarningdialog = gtk_dialog_new_with_buttons
 					(_("xlog - exporting"),
-					GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 				temp = g_strdup_printf
