@@ -930,7 +930,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 		GtkWidget *dialog;
 
 		dialog = gtk_message_dialog_new (GTK_WINDOW (mainwindow),
-			GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 			"%s", error->message);
 		g_error_free (error);
 		g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
