@@ -61,7 +61,7 @@ static void open_help (gchar *filename)
 
 	title = g_strdup_printf ("xlog - %s", filename);
 	helpdialog = gtk_dialog_new_with_buttons (title,
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
 	ok_button = gtk_dialog_add_button (GTK_DIALOG (helpdialog),
 		GTK_STOCK_OK, GTK_RESPONSE_OK);
 	g_free (title);
