@@ -114,6 +114,9 @@ on_importlogbutton_clicked (GtkButton * button, gpointer user_data)
 	fileselection = gtk_file_chooser_dialog_new (_("xlog - select a log for import"),
     	GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, 
 		GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+	gtk_window_set_modal (GTK_WINDOW(fileselection), TRUE);
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(fileselection), TRUE);
+
 	gtk_file_chooser_set_current_folder
 		(GTK_FILE_CHOOSER (fileselection), preferences.savedir);
 
