@@ -149,7 +149,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (page >= 0)
 	{
 		logeditor = gtk_dialog_new_with_buttons (_("xlog - logeditor"),
-			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 		hbox = gtk_hbox_new (FALSE, 0);
