@@ -36,6 +36,7 @@
 #include "gui_defaultsdialog.h"
 #include "gui_dialogsdialog.h"
 #include "gui_dupecheckdialog.h"
+#include "gui_dxcccheck.h"
 #include "gui_dxcclist.h"
 #include "gui_openlogdialog.h"
 #include "gui_helpdialog.h"
@@ -183,6 +184,7 @@ static GtkActionEntry entries[] =
   { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
 #endif
 
+  { "DXCC Check", GTK_STOCK_SPELL_CHECK, N_("Find unknown countries..."), "<control><shift>F", NULL, G_CALLBACK(on_menu_dxcccheck_activate) },
   { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "<control><shift>C", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
   { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "<control><shift>E", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
   { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "<control><shift>T", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
@@ -276,6 +278,7 @@ static const char *ui_description =
 "	 </menu>"
 "	 <menu action='ToolsMenu'>"
 "		<menuitem action='Dupe Check'/>"
+"		<menuitem action='DXCC Check'/>"
 "		<menuitem action='Log Editor'/>"
 "		<menuitem action='Trace Hamlib'/>"
 "		<menuitem action='Sort'/>"
