@@ -76,8 +76,6 @@ void savekeyer (void)
 	preferences.cwf12 = gtk_editable_get_chars (GTK_EDITABLE (f12entry), 0, -1);
 	preferences.cwcq = gtk_editable_get_chars (GTK_EDITABLE (cqentry), 0, -1);
 	preferences.cwsp = gtk_editable_get_chars (GTK_EDITABLE (spentry), 0, -1);
-
-	netkeyer_close ();
 }
 
 /* delete keyer window and save settings, close connection to cwdaemon */
@@ -86,6 +84,7 @@ on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	gpointer user_data)
 {
 	savekeyer ();
+	netkeyer_close ();
 	keyerwindow = NULL;
 
 	return FALSE;
@@ -98,7 +97,7 @@ void cw (GtkButton *button, gpointer user_data)
 	gchar *entryname, *sendstr, *call, *countstr, *lastmsg;
 	gint i, result = 0;
 
-	entryname = g_strdup_printf("%sentry", (gchar *)user_data);
+	entryname = g_strdup_printf("f%dentry", GPOINTER_TO_INT(user_data));
 	entry = lookup_widget (keyerwindow, entryname);
 	callentry = lookup_widget (mainwindow, "callentry");
 	count = lookup_widget (keyerwindow, "count");
@@ -168,55 +167,55 @@ on_keyerwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	{
 	case GDK_F1:
 		f1button = lookup_widget (keyerwindow, "f1button");
-		g_signal_emit_by_name (G_OBJECT (f1button), "activate");
+		gtk_widget_activate (f1button);
 	break;
 	case GDK_F2:
 		f2button = lookup_widget (keyerwindow, "f2button");
-		g_signal_emit_by_name (G_OBJECT (f2button), "activate");
+		gtk_widget_activate (f2button);
 	break;
 	case GDK_F3:
 		f3button = lookup_widget (keyerwindow, "f3button");
-		g_signal_emit_by_name (G_OBJECT (f3button), "activate");
+		gtk_widget_activate (f3button);
 	break;
 	case GDK_F4:
 		f4button = lookup_widget (keyerwindow, "f4button");
-		g_signal_emit_by_name (G_OBJECT (f4button), "activate");
+		gtk_widget_activate (f4button);
 	break;
 	case GDK_F5:
 		f5button = lookup_widget (keyerwindow, "f5button");
-		g_signal_emit_by_name (G_OBJECT (f5button), "activate");
+		gtk_widget_activate (f5button);
 	break;
 	case GDK_F6:
 		f6button = lookup_widget (keyerwindow, "f6button");
-		g_signal_emit_by_name (G_OBJECT (f6button), "activate");
+		gtk_widget_activate (f6button);
 	break;
 	case GDK_F7:
 		f7button = lookup_widget (keyerwindow, "f7button");
-		g_signal_emit_by_name (G_OBJECT (f7button), "activate");
+		gtk_widget_activate (f7button);
 	break;
 	case GDK_F8:
 		f8button = lookup_widget (keyerwindow, "f8button");
-		g_signal_emit_by_name (G_OBJECT (f8button), "activate");
+		gtk_widget_activate (f8button);
 	break;
 	case GDK_F9:
 		f9button = lookup_widget (keyerwindow, "f9button");
-		g_signal_emit_by_name (G_OBJECT (f9button), "activate");
+		gtk_widget_activate (f9button);
 	break;
 	case GDK_F10:
 		f10button = lookup_widget (keyerwindow, "f10button");
-		g_signal_emit_by_name (G_OBJECT (f10button), "activate");
+		gtk_widget_activate (f10button);
 	break;
 	case GDK_F11:
 		f11button = lookup_widget (keyerwindow, "f11button");
-		g_signal_emit_by_name (G_OBJECT (f11button), "activate");
+		gtk_widget_activate (f11button);
 	break;
 	case GDK_F12:
 		f12button = lookup_widget (keyerwindow, "f12button");
-		g_signal_emit_by_name (G_OBJECT (f12button), "activate");
+		gtk_widget_activate (f12button);
 	break;
 	case GDK_Escape:
 		stopbutton = lookup_widget (keyerwindow, "stopbutton");
-		g_signal_emit_by_name (G_OBJECT (stopbutton), "activate");
+		gtk_widget_activate (stopbutton);
 	break;
 	case GDK_Up:
 		if ((preferences.hamlib > 0) && (event->state & GDK_CONTROL_MASK))
@@ -441,12 +440,12 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 
 	hbox6 = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (keyervbox), hbox6, FALSE, FALSE, 0);
-	wpm_adj = gtk_adjustment_new (10, 5, 60, 1, 2, 10);
+	wpm_adj = gtk_adjustment_new (10, 5, 60, 1, 2, 0);
 	wpm = gtk_spin_button_new (GTK_ADJUSTMENT (wpm_adj), 1, 0);
 	gtk_box_pack_start (GTK_BOX (hbox6), wpm, FALSE, FALSE, 0);
 	wpmcountlabel = gtk_label_new ("<wpm|count>");
 	gtk_box_pack_start (GTK_BOX (hbox6), wpmcountlabel, FALSE, FALSE, 0);
-	count_adj = gtk_adjustment_new (1, 1, 10000, 1, 10, 10);
+	count_adj = gtk_adjustment_new (1, 1, 10000, 1, 10, 0);
 	count = gtk_spin_button_new (GTK_ADJUSTMENT (count_adj), 1, 0);
 	gtk_box_pack_start (GTK_BOX (hbox6), count, FALSE, FALSE, 0);
 
@@ -566,18 +565,18 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 		G_CALLBACK (on_keyerwindow_delete_event), NULL);
 	g_signal_connect ((gpointer) keyerwindow, "key_press_event",
 		G_CALLBACK (on_keyerwindow_keypress), NULL);
-	g_signal_connect (G_OBJECT (f1button), "clicked", G_CALLBACK (cw), "f1");
-	g_signal_connect (G_OBJECT (f2button), "clicked", G_CALLBACK (cw), "f2");
-	g_signal_connect (G_OBJECT (f3button), "clicked", G_CALLBACK (cw), "f3");
-	g_signal_connect (G_OBJECT (f4button), "clicked", G_CALLBACK (cw), "f4");
-	g_signal_connect (G_OBJECT (f5button), "clicked", G_CALLBACK (cw), "f5");
-	g_signal_connect (G_OBJECT (f6button), "clicked", G_CALLBACK (cw), "f6");
-	g_signal_connect (G_OBJECT (f7button), "clicked", G_CALLBACK (cw), "f7");
-	g_signal_connect (G_OBJECT (f8button), "clicked", G_CALLBACK (cw), "f8");
-	g_signal_connect (G_OBJECT (f9button), "clicked", G_CALLBACK (cw), "f9");
-	g_signal_connect (G_OBJECT (f10button), "clicked", G_CALLBACK (cw), "f10");
-	g_signal_connect (G_OBJECT (f11button), "clicked", G_CALLBACK (cw), "f11");
-	g_signal_connect (G_OBJECT (f12button), "clicked", G_CALLBACK (cw), "f12");
+	g_signal_connect (G_OBJECT (f1button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(1));
+	g_signal_connect (G_OBJECT (f2button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(2));
+	g_signal_connect (G_OBJECT (f3button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(3));
+	g_signal_connect (G_OBJECT (f4button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(4));
+	g_signal_connect (G_OBJECT (f5button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(5));
+	g_signal_connect (G_OBJECT (f6button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(6));
+	g_signal_connect (G_OBJECT (f7button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(7));
+	g_signal_connect (G_OBJECT (f8button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(8));
+	g_signal_connect (G_OBJECT (f9button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(9));
+	g_signal_connect (G_OBJECT (f10button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(10));
+	g_signal_connect (G_OBJECT (f11button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(11));
+	g_signal_connect (G_OBJECT (f12button), "clicked", G_CALLBACK (cw), GINT_TO_POINTER(12));
 	g_signal_connect (G_OBJECT (stopbutton), "clicked", G_CALLBACK (stop), NULL);
 	g_signal_connect (G_OBJECT (wpm), "value_changed", G_CALLBACK (change_wpm), NULL);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(keyertext));
@@ -587,5 +586,5 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 
 	gtk_widget_grab_focus (wpm);
 	gtk_widget_show_all (keyerwindow);
-	gtk_window_present (GTK_WINDOW(mainwindow));
+//	gtk_window_present (GTK_WINDOW(mainwindow));
 }
