@@ -213,7 +213,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/**************************/
 
 	preferencesdialog = gtk_dialog_new_with_buttons (_("xlog - preferences"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
 		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	preferencesnotebook = gtk_notebook_new ();
