@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,15 +25,17 @@
  */
 
 #include <gtk/gtk.h>
-#include "preferences.h"
+#include <string.h>
+
+#include "cfg.h"
 #include "log.h"
 #include "support.h"
 #include "xlog_enum.h"
 
 extern GtkUIManager *ui_manager;
+extern GtkWidget *mainnotebook;
 extern GList *logwindowlist;
 extern preferencestype preferences;
-
 /* configure "Tabs" menu */
 void set_tabs_menu (void)
 {
@@ -153,3 +155,41 @@ activate_modeoption_by_enum (GtkWidget *combo, gchar *prefs, guint enummode)
 	}
 	if (spl) g_strfreev (spl);
 }
+
+/*
+ * return the last exchange message in the log. If none found then return
+ * the initial exchange message. In case the mode field is empty return
+ * some fallbacks depending on the reportlength
+ */
+gchar*
+get_last_msg (void)
+{
+	GtkTreeIter iter;
+	gchar *rst, *mode, *suffix;
+	gchar *res = preferences.initlastmsg;
+
+	guint page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
+	logtype *logw = g_list_nth_data (logwindowlist, page);
+	GtkListStore *model = GTK_LIST_STORE(gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview)));
+	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL(model), &iter))
+	{
+		gtk_tree_model_get (GTK_TREE_MODEL(model), &iter, MYRST, &rst, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL(model), &iter, MODE, &mode, -1);
+		if (strlen(mode) > 0)
+		{
+			guint modeenum = mode2enum (mode);
+			suffix = rst + reportlen (modeenum);
+		}
+		else
+		{
+			if (g_strrstr (rst, "599"))
+				suffix = rst + 3;
+			else if (g_strrstr (rst, "59"))
+				suffix = rst + 2;
+			else
+				suffix = rst;
+		}
+		if (*suffix) res = suffix;
+	}
+	return g_strdup (res);
+}
