@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -27,22 +27,22 @@
 #include <hamlib/rig.h>
 
 #include "hamlib-utils.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "utils.h"
 #include "support.h"
 #include "main.h"
 #include "gui_warningdialog.h"
 
-#include "data/pixmaps/s0.xpm"
-#include "data/pixmaps/s1.xpm"
-#include "data/pixmaps/s2.xpm"
-#include "data/pixmaps/s3.xpm"
-#include "data/pixmaps/s4.xpm"
-#include "data/pixmaps/s5.xpm"
-#include "data/pixmaps/s6.xpm"
-#include "data/pixmaps/s7.xpm"
-#include "data/pixmaps/s8.xpm"
-#include "data/pixmaps/s9.xpm"
+#include "../data/pixmaps/s0.xpm"
+#include "../data/pixmaps/s1.xpm"
+#include "../data/pixmaps/s2.xpm"
+#include "../data/pixmaps/s3.xpm"
+#include "../data/pixmaps/s4.xpm"
+#include "../data/pixmaps/s5.xpm"
+#include "../data/pixmaps/s6.xpm"
+#include "../data/pixmaps/s7.xpm"
+#include "../data/pixmaps/s8.xpm"
+#include "../data/pixmaps/s9.xpm"
 
 struct rig_id {
 	const gint modelnr;
@@ -157,7 +157,7 @@ start_hamlib (gint rigid, gchar *device, gint debugmode, gint timervalue)
 
 	rig_set_debug (debugmode);
 	myrig = rig_init (rigid);
-	if (g_ascii_strcasecmp (preferences.rigconf, "?"))
+	if (strlen(preferences.rigconf) > 0)
 	{
 		retcode = set_conf(myrig, preferences.rigconf);
 		if (retcode != RIG_OK) 
