@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,21 +25,25 @@
  */
 
 #include <gtk/gtk.h>
-#include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
 #include <sys/types.h>
+#include <glib/gstdio.h>
+
+#ifndef G_OS_WIN32
 #include <sys/wait.h>
+#endif
 
 #include "callbacks_mainwindow_list.h"
 #include "gui_utils.h"
 #include "utils.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "support.h"
 #include "main.h"
+#include "dxcc.h"
 
 extern GtkWidget *mainnotebook;
 extern programstatetype programstate;
@@ -54,10 +58,10 @@ backuplog (gchar * filename, gchar * backupfilename)
 	gchar *msg;
 	FILE *in, *out;
 
-	in = fopen (filename, "r");
+	in = g_fopen (filename, "r");
 	if (in)
 	{
-		out = fopen (backupfilename, "w");
+		out = g_fopen (backupfilename, "w");
 		if (out)
 		{
 			while ((ch = getc (in)) != EOF)
@@ -303,7 +307,7 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 {
 	logtype *logwindow;
 	gint i, j;
-	gchar *logn, **w, *labelname;
+	gchar *logn, *labelname;
 	GtkCellRenderer *renderer, *brenderer;
 	GtkTreeViewColumn *column;
 	GObject *selection;
@@ -322,6 +326,7 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING);
 	logwindow->treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (logwindow->treeview), -1);
 	g_object_unref (G_OBJECT (model));
 
 	/* add callback for selecting a row */
@@ -334,9 +339,6 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 	for (j = 0; j < logwindow->columns; j++)
 		logwindow->logfields[j] = lp->column_fields[j];
 
-	/* column widths */
-	w = g_strsplit(preferences.logcwidths2, ",", 0);
-
 	/* NR column is the first one */
 	renderer = gtk_cell_renderer_text_new ();
 	brenderer = gtk_cell_renderer_text_new ();
@@ -345,10 +347,10 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN (column), TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (logwindow->treeview), column);
-	if (atoi(w[NR]) == 0)
+	if (preferences.logcwidths2[NR] == 0)
 		gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 	else
-		gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), atoi(w[NR]));
+		gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[NR]);
 
 	/* see which fields are in the log and add a column or hide it */
 	for (j = 1; j < QSO_FIELDS; j++)
@@ -377,13 +379,12 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 		gtk_tree_view_column_set_resizable
 			(GTK_TREE_VIEW_COLUMN(column), TRUE);
 		gtk_tree_view_column_set_fixed_width
-			(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
+			(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(logwindow->treeview), column);
 
 		if (i == lp->column_nr)
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 	}
-	g_strfreev (w);
 
 	g_object_set(G_OBJECT(logwindow->treeview), "fixed-height-mode", TRUE, NULL);
 	gtk_widget_show (logwindow->treeview);
@@ -405,6 +406,7 @@ openlogwindow (LOGDB * lp, gchar * name, gint page)
 }
 
 /* close child process when finished */
+#ifndef G_OS_WIN32
 static gboolean
 childcheck (void)
 {
@@ -413,15 +415,49 @@ childcheck (void)
   childpid = waitpid (-1, &status, WNOHANG);
   return (WIFEXITED(status) == 0);
 }
+#endif
+
+typedef gchar *item_t[QSO_FIELDS];
+static int savelog_compar_groupbycall(const void *b, const void *a)
+{
+	const gchar **item_a, **item_b;
+	item_a = (const gchar **)a;
+	item_b = (const gchar **)b;
+
+	return strcmp(item_a[CALL], item_b[CALL]);
+}
+
+
+extern GPtrArray *dxcc;
+static int savelog_compar_sortbydxcc(const void *b, const void *a)
+{
+	gint rescmp;
+	gchar **item_a, **item_b;
+	item_a = (gchar **)a;
+	item_b = (gchar **)b;
+
+	struct info info_a, info_b;
+	info_a = lookupcountry_by_callsign (item_a[CALL]);
+	info_b = lookupcountry_by_callsign (item_b[CALL]);
+	dxcc_data *d_a = g_ptr_array_index (dxcc, info_a.country);
+	dxcc_data *d_b = g_ptr_array_index (dxcc, info_b.country);
+
+	/* Sort by DXCC first, then group by call sign within same DXCC */
+	rescmp = strcmp(d_b->px, d_a->px);
+	if (rescmp != 0)
+		return rescmp;
+	return strcmp(item_a[CALL], item_b[CALL]);
+}
 
 /* saving of the log */
 void
 savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 {
 	LOGDB *lp;
-	gint i, j, pid;
+	gint i, j, k, pid, exported;
 	G_CONST_RETURN gchar *label;
-	gchar **item, *pathstr;
+	gchar *pathstr;
+	item_t *sorteditems;
 	gint fields[QSO_FIELDS], widths[QSO_FIELDS];
 	logtype *logw = (logtype *) arg;
 	GtkTreeViewColumn *column;
@@ -429,10 +465,8 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 	GtkTreePath *path;
 	GtkTreeIter iter;
 
-	item = g_new0 (gchar *, QSO_FIELDS);
-
 	/* how many columns do we have and what are the labels, skip first field */
-	/* ----> unknown fields have a fixed label */
+	/* NOTE: unknown fields have a fixed label */
 	for (i = 0; i < logw->columns; i++)
 	{
 		column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), logw->logfields[i]);
@@ -446,70 +480,88 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 		widths[i] = parse_field_width (fields[i]);
 	}
 
+#ifndef G_OS_WIN32
 	pid = fork (); /* use fork for log saving */
-	if (pid == 0)
+	if (pid == -1)
+		g_warning(_("fork failed when saving log: %s"), g_strerror (errno));
+#else
+	pid = 0;
+#endif
+
+if (pid == 0) { /* this is the child */
+	lp = log_file_create (logfile, type, logw->columns, fields, widths);
+	k = 0;
+	if (lp)
 	{
-		lp = log_file_create (logfile, type, logw->columns, fields, widths);
-		if (lp)
+		model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
+		exported = last - first + 1;
+		/* create an array to be used for sorting */
+		sorteditems = g_new0 (item_t, exported);
+		/* go through the QSO's and store in the sort array */
+		for (i = logw->qsos - first; i >= logw->qsos - last; i--)
 		{
-			model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
-			for (i = logw->qsos - first; i >= logw->qsos - last; i--)
+			pathstr = g_strdup_printf ("%d", i);
+			path = gtk_tree_path_new_from_string (pathstr);
+			gtk_tree_model_get_iter (model, &iter, path);
+			for (j = 0; j < logw->columns; j++)
 			{
-				pathstr = g_strdup_printf ("%d", i);
-				path = gtk_tree_path_new_from_string (pathstr);
-				gtk_tree_model_get_iter (model, &iter, path);
-				for (j = 0; j < logw->columns; j++)
-				{
-					gtk_tree_model_get
-						(model, &iter, logw->logfields[j], &item[fields[j]], -1);
-					if (fields[j] == DATE || fields[j] == NAME ||
-fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
-						item[fields[j]] = g_locale_from_utf8
-							(item[fields[j]], -1, NULL, NULL, NULL);
-				}
-				log_file_qso_append (lp, item);
-				gtk_tree_path_free (path);
-				g_free (pathstr);
+				gtk_tree_model_get (model, &iter, logw->logfields[j], &sorteditems[k][fields[j]], -1);
+if (fields[j] == DATE || fields[j] == NAME || fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
+	sorteditems[k][fields[j]] = g_locale_from_utf8 (sorteditems[k][fields[j]], -1, NULL, NULL, NULL);
 			}
-			log_file_close (lp);
-			_exit (0);
+			k++;
+			gtk_tree_path_free (path);
+			g_free (pathstr);
 		}
-	}
-	/* check the child every second */
+
+		if (type == TYPE_LABELS)
+		{
+			if (preferences.tsvsortbydxcc)
+				qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_sortbydxcc);
+			else if (preferences.tsvgroupbycallsign > 1)
+				qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_groupbycall);
+		}
+
+		/* QSO's have been sorted (or not), now save them */
+		for (i = 0; i <= exported -1; i++)
+			log_file_qso_append (lp, sorteditems[i]);
+		/* free the sortarray */
+		g_free(sorteditems);
+
+		log_file_close (lp);
+#ifndef G_OS_WIN32
+		_exit (0);
+#else
+		return;
+#endif
+	} }
+	/* parent running */
+#ifndef G_OS_WIN32
 	g_timeout_add (1000, (GSourceFunc) childcheck, NULL);
-	g_free (item);
+#endif
 }
 
 
 /* look for logs in dir */
-GString *
-getlogs (gchar *path, gchar *patt)
+GPtrArray*
+getxlogs (gchar *path, gchar *patt)
 {
-	gchar *pattern;
-	GString *logs = g_string_new ("");
-	const gchar *dirname;
 	GError *error  = NULL;
-	GDir *dir;
 
-	dir = g_dir_open (path, 0, &error);
-	pattern = g_strdup_printf ("%s.xlog", patt);
+ 	GDir *dir = g_dir_open (path, 0, &error);
+	gchar *pattern = g_strdup_printf ("%s.xlog", patt);
+ 	GPtrArray *arr = g_ptr_array_new ();
 	if (!error)
 	{
-		dirname = g_dir_read_name (dir);
+		const gchar *dirname = g_dir_read_name (dir);
 		while (dirname)
 		{
 			if (g_pattern_match_simple (pattern, dirname))
-			{
-				if (g_str_has_suffix (dirname, ".xlog"))
-				{
-					g_string_append (logs, dirname);
-					g_string_append_c (logs, '\n');
-				}
-			}
+				g_ptr_array_add (arr, g_strdup(dirname));
 			dirname = g_dir_read_name (dir);
 		}
 		g_dir_close (dir);
 	}
 	g_free (pattern);
-	return (logs);
+	return (arr);
 }
