@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -30,20 +30,20 @@
 #include <stdlib.h>
 #include <strings.h>
 #include <string.h>
-#include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <glib.h>
 #include <locale.h>
+#include <glib/gstdio.h>
 
 #include "logfile.h"
-#include "preferences.h"
-#include "utils.h"
-#include "xlog_enum.h"
+#include "../cfg.h"
+#include "../utils.h"
+#include "../xlog_enum.h"
 
 #ifndef HAVE_STRPTIME
-#include "strptime.h"
+#include "../strptime.h"
 #define strptime(s,f,t) mystrptime(s,f,t)
 #endif
 
@@ -160,35 +160,8 @@ static gint adif_qso_foreach
 						if (!q[BAND])
 						{
 							adif_field = BAND;
-							if (g_strrstr(adifitem[1], "m") ||
-								g_strrstr(adifitem[1], "M"))
-							{ /* convert band to freq */
-					if (g_ascii_strncasecmp (adifitem[1], "160", 3) == 0)
-						q[adif_field] = g_strdup ("1.8");
-					else if (g_ascii_strncasecmp (adifitem[1], "80", 2) == 0)
-						q[adif_field] = g_strdup ("3.5");
-					else if (g_ascii_strncasecmp (adifitem[1], "60", 2) == 0)
-						q[adif_field] = g_strdup ("5.3");
-					else if (g_ascii_strncasecmp (adifitem[1], "40", 2) == 0)
-						q[adif_field] = g_strdup ("7");
-					else if (g_ascii_strncasecmp (adifitem[1], "20", 2) == 0)
-						q[adif_field] = g_strdup ("14");
-					else if (g_ascii_strncasecmp (adifitem[1], "15", 2) == 0)
-						q[adif_field] = g_strdup ("21");
-					else if (g_ascii_strncasecmp (adifitem[1], "10", 2) == 0)
-						q[adif_field] = g_strdup ("28");
-					else if (g_ascii_strncasecmp (adifitem[1], "30", 2) == 0)
-						q[adif_field] = g_strdup ("10");
-					else if (g_ascii_strncasecmp (adifitem[1], "17", 2) == 0)
-						q[adif_field] = g_strdup ("18");
-					else if (g_ascii_strncasecmp (adifitem[1], "12", 2) == 0)
-						q[adif_field] = g_strdup ("24");
-					else
-						q[adif_field] =	g_strndup (adifitem[1], atoi(adifid[1]));
-							}
-							else
-								q[adif_field] =
-									g_strndup (adifitem[1], atoi(adifid[1]));
+							guint enumband = meters2enum (adifitem[1]);
+							q[adif_field] = band_enum2char (enumband);
 						}
 					}
 					else if (!strcasecmp (adifid[0], "FREQ"))
@@ -336,7 +309,7 @@ gint adif_open(LOGDB *handle)
 	const gint xlog_fields [] = {DATE, GMT, GMTEND, CALL, BAND, MODE, RST, MYRST,
 		QSLOUT, QSLIN, POWER, NAME, QTH, LOCATOR, U1, U2, REMARKS};
 
-	fp = fopen(handle->path, "r");
+	fp = g_fopen(handle->path, "r");
 	if (!fp) return -1;
 	handle->priv = (gpointer)fp;
 
@@ -356,7 +329,7 @@ gint adif_create(LOGDB *handle)
 	time_t timet;
 	gchar sdate[32];
 
-	fp = fopen(handle->path, "w");
+	fp = g_fopen(handle->path, "w");
 	if (!fp) return -1;
 	handle->priv = (gpointer)fp;
 
@@ -368,7 +341,7 @@ gint adif_create(LOGDB *handle)
 
 	/* write header */
 	fprintf(fp, "ADIF Export from " PACKAGE " Version " VERSION "\n"
-				"Copyright (C) 2001-2007 Joop Stakenborg <pg4i@amsat.org>\n"
+				"Copyright (C) 2001-2008 Joop Stakenborg <pg4i@amsat.org>\n"
 				"Internet:  http://pg4i.chronos.org.uk/linux/xlog.html\n\n"
 				"Date of export: %s\n",
 				sdate);
@@ -425,49 +398,6 @@ static const gchar *xlog2adif_name(gint fld)
 		}
 }
 
-/* TODO: can we use enu, functions here? */
-static gchar *freq2band (gchar *freq)
-{
-
-	if ((strlen(freq) == 1) || (freq[1] == '.'))
-	{
-		if (strlen(freq) > 1) freq[1] = '\0';
-		switch (atoi(freq))
-		{
-			case 1: return "160M";
-			case 3: return "80M";
-			case 5: return "60M";
-			case 7: return "40M";
-		}
-	}
-	else if ((strlen(freq) == 2) || (freq[2] == '.'))
-	{
-		if (strlen(freq) > 2) freq[2] = '\0';
-		switch (atoi(freq))
-		{
-			case 10: return "30M";
-			case 14: return "20M";
-			case 18: return "17M";
-			case 21: return "15M";
-			case 24: return "12M";
-			case 28 ... 29: return "10M";
-			case 50 ... 54: return "6M";
-			case 70: return "4M";
-
-		}
-	}
-	else if ((strlen(freq) == 3) || (freq[3] == '.'))
-	{
-		if (strlen(freq) > 3) freq[3] = '\0';
-		switch (atoi(freq))
-		{
-			case 144 ... 148: return "2M";
-			case 222 ... 225: return "1.25M";
-		}
-	}
-	return "?";
-}
-
 gint adif_qso_append(LOGDB *handle, const qso_t *q)
 {
 	FILE *fp = (FILE *)handle->priv;
@@ -513,7 +443,8 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 				qfield = q[fld];
 			else
 			{
-				qfield = freq2band (q[fld]);
+				guint bandenum = freq2enum (q[fld]);
+				qfield = band_enum2bandchar (bandenum);
 				qfield_len = strlen(qfield);
 			}
 		}
