@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,7 +25,6 @@
  */
 
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
 #include <locale.h>
 #ifndef __USE_XOPEN
@@ -33,9 +32,10 @@
 #endif
 #include <time.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #ifndef HAVE_STRPTIME
-#include "strptime.h"
+#include "../strptime.h"
 #define strptime(s,f,t) mystrptime(s,f,t)
 #endif
 
@@ -70,7 +70,7 @@ oh1aa_open (LOGDB * handle)
 	FILE *fp;
 	const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST, REMARKS};
 
-	fp = fopen (handle->path, "r");
+	fp = g_fopen (handle->path, "r");
 	if (!fp) return -1;
 	handle->priv = (gpointer) fp;
 
