@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -26,8 +26,8 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <stdio.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #include "logfile.h"
 
@@ -68,7 +68,7 @@ twlog_open (LOGDB * handle)
   FILE *fp;
 	const gint xlog_fields [] = {DATE, GMT, GMTEND, CALL, BAND, MODE, RST, MYRST, POWER, REMARKS};
 
-  fp = fopen (handle->path, "r");
+  fp = g_fopen (handle->path, "r");
   if (!fp)
     return -1;
   handle->priv = (gpointer) fp;
@@ -89,7 +89,7 @@ twlog_create (LOGDB * handle)
 {
   FILE *fp;
 
-  fp = fopen (handle->path, "w");
+  fp = g_fopen (handle->path, "w");
   if (!fp)
     return -1;
   handle->priv = (gpointer) fp;
