@@ -47,6 +47,8 @@
  * locator:<QRA locator, as used in VHF QSO's>
  * free1: <information to put in freefield1>
  * free2: <information to put in freefield2>
+ * ?: special command to use for dupechecking, used by eepkeyer, see:
+   http://www.hamsoftware.org/, requires data to be added to the qsoframe
  ****************************************************************************
  *
  * See sendtoxlog.c, included with the sources for examples.
@@ -163,6 +165,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		entry = my_strreplace (entry, "\n", " ");
 		entry = my_strreplace (entry, "\t", " ");
 		remoteinfo = g_strsplit (entry, "\1", 0);
+		gint dchk_only = 0;
 		for (;;)
 		{
 			if (remoteinfo[j] == NULL)
@@ -380,6 +383,10 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					}
 				}
 			}
+			else if (g_ascii_strncasecmp (remoteinfo[j], "?:", 2) == 0)
+			{
+				dchk_only = 1;
+			}
 		j++;
 		}
 		g_strfreev (remoteinfo);
@@ -414,7 +421,19 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 			else
 				qso[MODE] = gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
 		}
-	
+		
+		if (dchk_only == 1)
+		{
+			/* Only do a dupe check and exit */
+			/* qso[CALL] holds callsign to check */
+			if (strlen(qso[CALL]) > 0)
+			{
+				callentry = lookup_widget (mainwindow, "callentry");
+				gtk_entry_set_text (GTK_ENTRY (callentry), qso[CALL]);
+			}
+			return;
+		}
+			
 		if (preferences.remoteadding == 1 && logw)
 		{
 			qso[NR] = g_strdup_printf ("%d", ++logw->qsos);
@@ -438,6 +457,11 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				path, NULL, TRUE, 1.0, 0.0);
 			gtk_tree_path_free (path);
 			
+			
+			
+			
+
+
       /* save with every log change */
 			if (preferences.saving == 2)
 			{
