@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -95,6 +95,11 @@ enum /* modes taken from ADIF specs */
 };
 
 gchar *band_enum2char (guint band_enum);
+gchar *band_enum2cabrillochar (guint band_enum);
 gint freq2enum (gchar * str);
+gint hamlibfreq2enum (long long f);
+gchar *band_enum2bandchar (guint band_enum);
+gint meters2enum (gchar * str);
 gchar *mode_enum2char (guint mode_enum);
+gint reportlen(guint mode_enum);
 gint mode2enum (gchar * str);
